@@ -3,9 +3,10 @@
 /***********************************************************************
 *  This code is part of GLPK (GNU Linear Programming Kit).
 *
-*  Copyright (C) 2000,01,02,03,04,05,06,07,08,2009 Andrew Makhorin,
-*  Department for Applied Informatics, Moscow Aviation Institute,
-*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
+*  2009, 2010, 2011 Andrew Makhorin, Department for Applied Informatics,
+*  Moscow Aviation Institute, Moscow, Russia. All rights reserved.
+*  E-mail: <mao@gnu.org>.
 *
 *  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
@@ -213,7 +214,7 @@ void dmp_free_atom(DMP *pool, void *atom, int size)
 *  SYNOPSIS
 *
 *  #include "glpdmp.h"
-*  xlong_t dmp_in_use(DMP *pool);
+*  glp_long dmp_in_use(DMP *pool);
 *
 *  DESCRIPTION
 *
@@ -225,7 +226,7 @@ void dmp_free_atom(DMP *pool, void *atom, int size)
 *
 *  The routine returns the number of atoms which are still in use. */
 
-xlong_t dmp_in_use(DMP *pool)
+glp_long dmp_in_use(DMP *pool)
 {     return
          pool->count;
 }
